@@ -1,4 +1,4 @@
-ascii.htest <- function(x, include.rownames = TRUE, include.colnames = TRUE, format = "f", digits = 2, decimal.mark = ".", na.print = "", caption = "", caption.level = ".", width = 0, frame = "", grid = "", valign = "", header = TRUE, footer = FALSE, align = "", col.width = 1, style = "", ...){
+ascii.htest <- function(x, include.rownames = TRUE, include.colnames = TRUE, format = "f", digits = 2, decimal.mark = ".", na.print = "", caption = "", caption.level = ".", width = 0, frame = "", grid = "", valign = "", header = TRUE, footer = FALSE, align = "", col.width = 1, style = "", cgroup = NULL, n.cgroup = NULL, calign = "", cvalign = "", cstyle = "", rgroup = NULL, n.rgroup = NULL, ralign = "", rvalign = "", rstyle = "", ...){
   if (x$method == "Fisher's Exact Test for Count Data") {
     res <- cbind(x$estimate, x$conf.int[1], x$conf.int[2], x$p.value)
     colnames(res) <- c("Odds ratio", "lower .95", "upper .95", "p-value")
@@ -12,5 +12,7 @@ ascii.htest <- function(x, include.rownames = TRUE, include.colnames = TRUE, for
          digits = digits, decimal.mark = decimal.mark, na.print = na.print,
          caption = caption, caption.level = caption.level, width = width, frame = frame, grid = grid,
          valign = valign, header = header, footer = footer, align = align,
-         col.width = col.width, style = style)
+         col.width = col.width, style = style, cgroup = cgroup, n.cgroup = n.cgroup, calign = calign,
+         cvalign = cvalign, cstyle = cstyle, rgroup = rgroup, n.rgroup = n.rgroup, ralign = ralign,
+         rvalign = rvalign, rstyle = rstyle)
 }
