@@ -1,5 +1,5 @@
 # from xtable package
-ascii.ts <- function (x, include.rownames = TRUE, include.colnames = TRUE, format = "f", digits = 0, decimal.mark = ".", na.print = "", caption = "", caption.level = ".", width = 0, frame = "", grid = "", valign = "", header = TRUE, footer = FALSE, align = "", col.width = 1, style = "", ...){
+ascii.ts <- function (x, include.rownames = TRUE, include.colnames = TRUE, format = "f", digits = 0, decimal.mark = ".", na.print = "", caption = "", caption.level = ".", width = 0, frame = "", grid = "", valign = "", header = TRUE, footer = FALSE, align = "", col.width = 1, style = "", cgroup = NULL, n.cgroup = NULL, calign = "", cvalign = "", cstyle = "", rgroup = NULL, n.rgroup = NULL, ralign = "", rvalign = "", rstyle = "", ...){
 
   if (inherits(x, "ts") && !is.null(ncol(x))) {
     tp.1 <- trunc(time(x))
@@ -35,7 +35,9 @@ ascii.ts <- function (x, include.rownames = TRUE, include.colnames = TRUE, forma
       digits = digits, decimal.mark = decimal.mark, na.print = na.print,
       caption = caption, caption.level = caption.level, width = width, frame = frame, grid = grid,
       valign = valign, header = header, footer = footer, align = align,
-      col.width = col.width, style = style)
+      col.width = col.width, style = style, cgroup = cgroup, n.cgroup = n.cgroup, calign = calign,
+         cvalign = cvalign, cstyle = cstyle, rgroup = rgroup, n.rgroup = n.rgroup, ralign = ralign,
+         rvalign = rvalign, rstyle = rstyle)
   class(obj) <- c("ascii", "proto", "environment")
   return(obj)
 }
